package cn.iocoder.yudao.module.safe.service.server;

import jakarta.validation.*;
import cn.iocoder.yudao.module.safe.controller.admin.server.vo.*;
import cn.iocoder.yudao.module.safe.dal.dataobject.server.SafeServerDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import java.util.List;

/**
 * 安防后端设备 Service 接口
 *
 * @author caoyang
 */
public interface SafeServerService {

    /**
     * 创建安防后端设备
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createServer(@Valid AppSafeServerSaveReqVO createReqVO);

    /**
     * 更新安防后端设备
     *
     * @param updateReqVO 更新信息
     */
    void updateServer(@Valid AppSafeServerSaveReqVO updateReqVO);

    /**
     * 删除安防后端设备
     *
     * @param id 编号
     */
    void deleteServer(Long id);

    /**
     * 获得安防后端设备
     *
     * @param id 编号
     * @return 安防后端设备
     */
    SafeServerDO getServer(Long id);

    /**
     * 获得安防后端设备分页
     *
     * @param pageReqVO 分页查询
     * @return 安防后端设备分页
     */
    PageResult<SafeServerDO> getServerPage(AppSafeServerPageReqVO pageReqVO);

    /**
     * 获得所有后端设备信息
     * @return
     */
    public List<SafeServerDO> getAllServer();

}
